#! /bin/sh
#
# This script will perform the necessary upgrades needed 
# 
#


#intialize our path variables
if [ -f "/media/sdb1/afs_installx86/afs_image/afs_image.sh" ];then
    CARD_DIR="/media/sdb1/afs_installx86"
elif [ -f "/media/sdc1/afs_installx86/afs_image/afs_image.sh" ];then
    CARD_DIR="/media/sdc1/afs_installx86"
elif [ -f "/media/sdd1/afs_installx86/afs_image/afs_image.sh" ];then
    CARD_DIR="/media/sdd1/afs_installx86"
else
    CARD_DIR="/media/sde1/afs_installx86"
fi


INSTALL_DIR="/home/root/afs_installx86"
IMAGE_DIR="/home/root/afs_installx86/afs_image"
NXP_PORT="/dev/ttyS5"
BACKUP_DIR="/home/root/backup"
HOME_DIR="/home/root"
TEMP_DIR="/home/root/temp"
LOG_FILE="/home/root/logs/SYSLOG.ALS"
#   ---------------------------------------------
#   TrimDataLogs
#   Trim the datastore files to managable sizes
#   ---------------------------------------------
ContactSupportMessage()
{
    echo "Please remove SD card and"
    echo "Contact Support for assistance"
    dmesg > $INSTALL_DIR/afs_error.log #copy dmesg to card for support effort
    sync
    sleep 60
    reboot
}

#   ---------------------------------------------
#   Backup
#   Backup current home working directory
#   ---------------------------------------------
Backup()
{
    echo "Performing system backup..." >> $LOG_FILE

    #copy backups into $BACKUP_DIR for safe keeping
    if [ -f "$BACKUP_DIR/afs_backup.tar.gz" ]; then
        echo "Previous config backup detected moving to afs_backup.tar.gz.bak" >> $LOG_FILE
        mv "$BACKUP_DIR/afs_backup.tar.gz" "$BACKUP_DIR/afs_backup.tar.gz.bak"
    fi 

    if [ -f "$BACKUP_DIR/afs_datalogs.tar.gz" ]; then
        echo "Previous datalogs backup detected moving to afs_datalogs.tar.gz.bak" >> $LOG_FILE
        mv "$BACKUP_DIR/afs_datalogs.tar.gz" "$BACKUP_DIR/afs_datalogs.tar.gz.bak"
    fi 

  # Check for config files if there are none something bad happened and we should
  # restore from defaults
    if ! [ -d "$HOME_DIR/cfg" ]; then
        if [ -f "$BACKUP_DIR/afs_backup.tar.gz.bak" ]; then
            echo "WARNING: config files missing... restoring from backup" >> $LOG_FILE
            mv "$BACKUP_DIR/afs_backup.tar.gz.bak" "$BACKUP_DIR/afs_backup.tar.gz"
            tar -xzf "$BACKUP_DIR/afs_backup.tar.gz" -C "$HOME_DIR" #rebuild alternate /home/root
        else
            if [ -f "$IMAGE_DIR/sysinit.tar.gz" ]; then
                tar -xzf "$IMAGE_DIR/sysinit.tar.gz" -C "$HOME_DIR" #rebuild alternate /home/root
            else
                echo "ERROR: Config files not found" >> $LOG_FILE
                ContactSupportMessage
            fi
        fi
    fi

  #make the backup file
    if [ -d "$HOME_DIR/cfg" ]; then
        tar -czvf "$HOME_DIR/afs_backup.tar.gz" -C "$HOME_DIR" cfg logs sounds afsnvram1 afsnvram2
        sync
        if [ -f "$HOME_DIR/afs_backup.tar.gz" ]; then
            cp -f "$HOME_DIR/afs_backup.tar.gz" "$BACKUP_DIR/afs_backup.tar.gz"
        fi
    fi

    sync

    echo "Backup complete" >> $LOG_FILE
    return 0;
}


#   ---------------------------------------------
#   FinalUpdates
#   Apply patches and update AFEs
#   ---------------------------------------------
FinalUpdates()
{
# Copy contents of card to the on-disk directory

    echo "Coping Install image to disk" >> $LOG_FILE
    cp -af $CARD_DIR $INSTALL_DIR
 
# Update FileSystem drivers
    if [ -f "$IMAGE_DIR/afs_fspatch.tar.gz" ]; then
        echo "Updating File System" >> $LOG_FILE
        tar -xzf $IMAGE_DIR/afs_fspatch.tar.gz -C /
        sync
        echo "File System Update Complete" >> $LOG_FILE
    fi

# SysInit Option 
# if install card includes sysinit.tar.gz extract it into /home/root
    if [ -f "$IMAGE_DIR/sysinit.tar.gz" ]; then
        echo "sysinitstarted" > $INSTALL_DIR/sysinitstarted >> $LOG_FILE
        sync
        echo "Initializing default data from sysinit.tar.gz" >> $LOG_FILE
        tar -xzf $IMAGE_DIR/sysinit.tar.gz -C $HOME_DIR
        rm -f $INSTALL_DIR/sysinitstarted
        sync
    fi


# AF5000.AFE
    
    if [ -f "$INSTALL_DIR/AF5000.AFE" ]; then
        echo "Upgrading AF5000.AFE From SD Card" >> $LOG_FILE
        mv -f $INSTALL_DIR/AF5000.AFE $HOME_DIR/AF5000.AFE
        sync
        sleep 1
   elif [ -f "$INSTALL_DIR/af5000.afe" ]; then
        echo "Upgrading AF5000.AFE From SD Card" >> $LOG_FILE
        mv -f $INSTALL_DIR/af5000.afe $HOME_DIR/AF5000.AFE
        sync
        sleep 1
    else
        echo "AF5000.AFE file not found" >> $LOG_FILE
    fi

# AFSMON.AFE
    if [ -f "$INSTALL_DIR/AFSMON.AFE" ]; then
        echo "Upgrading AFSMON.AFE From SD Card" >> $LOG_FILE
        mv -f $INSTALL_DIR/AFSMON.AFE $HOME_DIR/AFSMON.AFE
        sync
        sleep 1
   elif [ -f "$INSTALL_DIR/afsmon.afe" ]; then
        echo "Upgrading AFSMON.AFE From SD Card" >> $LOG_FILE
        mv -f $INSTALL_DIR/afsmon.afe $HOME_DIR/AFSMON.AFE
        sync
        sleep 1
    else
        echo "AFSMON.AFE file not found" >> $LOG_FILE
    fi

# SRVXM.AFE
    if [ -f "$INSTALL_DIR/SRVXM.AFE" ]; then
        echo "Upgrading SRVXM.AFE From SD Card" >> $LOG_FILE
        mv -f $INSTALL_DIR/SRVXM.AFE $HOME_DIR/SRVXM.AFE
        sync
        sleep 1
   elif [ -f "$INSTALL_DIR/srvxm.afe" ]; then
        echo "Upgrading SRVXM.AFE From SD Card" >> $LOG_FILE
        mv -f $INSTALL_DIR/srvxm.afe $HOME_DIR/SRVXM.AFE
        sync
        sleep 1
    else
        echo "SRVXM.AFE file not found" >> $LOG_FILE
    fi

# SRVFISB.AFE
    if [ -f "$INSTALL_DIR/SRVFISB.AFE" ]; then
        echo "Upgrading SRVFISB.AFE From SD Card" >> $LOG_FILE
        mv -f $INSTALL_DIR/SRVFISB.AFE $HOME_DIR/SRVFISB.AFE
        sync
        sleep 1
   elif [ -f "$INSTALL_DIR/srvfisb.afe" ]; then
        echo "Upgrading SRVFISB.AFE From SD Card" >> $LOG_FILE
        mv -f $INSTALL_DIR/srvfisb.afe $HOME_DIR/SRVFISB.AFE
        sync
        sleep 1
    else
        echo "SRVFISB.AFE file not found" >> $LOG_FILE
    fi

# SRVDSAB.AFE
    if [ -f "$INSTALL_DIR/SRVDSAB.AFE" ]; then
        echo "Upgrading SRVDSAB.AFE From SD Card" >> $LOG_FILE
        mv -f $INSTALL_DIR/SRVDSAB.AFE $HOME_DIR/SRVDSAB.AFE
        sync
        sleep 1
   elif [ -f "$INSTALL_DIR/srvdsab.afe" ]; then
        echo "Upgrading SRVDSAB.AFE From SD Card" >> $LOG_FILE
        mv -f $INSTALL_DIR/srvdsab.afe $HOME_DIR/SRVDSAB.AFE
        sync
        sleep 1
    else
        echo "SRVDSAB.AFE file not found" >> $LOG_FILE
    fi

# WBDEF.AFZ
    if [ -f "$INSTALL_DIR/WBDEF.AFZ" ]; then
        echo "Upgrading WBDEF.AFZ From SD Card" >> $LOG_FILE
        mv -f $INSTALL_DIR/WBDEF.AFZ $HOME_DIR/cfg/WBDEF.AFZ
        sync
        sleep 1
   elif [ -f "$INSTALL_DIR/wbdef.afz" ]; then
        echo "Upgrading WBDEF.AFZ From SD Card" >> $LOG_FILE
        mv -f $INSTALL_DIR/wbdef.afz $HOME_DIR/cfg/WBDEF.AFZ
        sync
        sleep 1
    else
        echo "WBDEF.AFZ file not found" >> $LOG_FILE
    fi

    return 0;
}

#   ---------------------------------------------
#   CleanUp
#   Clean up the temp dir that was used for install
#   ---------------------------------------------
CleanUp()
{
    if [ -d "$INSTALL_DIR" ]; then
        echo "Deleting the install directory" >> $LOG_FILE
        rm -rf $INSTALL_DIR
        sync
        sleep 1
    fi

    if [ -d "$HOME_DIR/INSTALL" ]; then
        echo "Deleting the old install directory" >> $LOG_FILE
        rm -rf "$HOME_DIR/INSTALL"
        sync
        sleep 1
    fi

}


#   ---------------------------------------------
#   CheckDirectories
#   Make sure basic directory structure is in place
#   ---------------------------------------------
CheckDirectories()
{
    if ! [ -d "$HOME_DIR/cfg" ]; then
        mkdir -p "$HOME_DIR/cfg"
    fi

    if ! [ -d "$HOME_DIR/datalogs" ]; then
        mkdir -p "$HOME_DIR/datalogs"
    fi

    if ! [ -d "$HOME_DIR/logs" ]; then
        mkdir -p "$HOME_DIR/logs"
    fi

    if ! [ -d "$HOME_DIR/sounds" ]; then
        mkdir -p "$HOME_DIR/sounds"
    fi

    if ! [ -d "$HOME_DIR/map" ]; then
        mkdir -p "$HOME_DIR/map"
    fi

    if ! [ -d "$HOME_DIR/wx/xm/srv" ]; then
        mkdir -p "$HOME_DIR/wx/xm/srv"
    fi

    if ! [ -d "$HOME_DIR/wx/fisb/srv" ]; then
        mkdir -p "$HOME_DIR/wx/fisb/srv"
    fi

    if ! [ -d "$BACKUP_DIR" ]; then
        mkdir -p "$BACKUP_DIR"
    fi

}



#   ---------------------------------------------
#   ---------------------------------------------
#   The work starts here
#   ---------------------------------------------
#   ---------------------------------------------

echo "Running Advanced Flight Systems Upgrade" >> $LOG_FILE

# move to /
cd $HOME_DIR

# Install Steps
# 1: Backup
# 2: Run Final updates

CheckDirectories  #make sure we have all the needed directories
#Backup            #make a backup
FinalUpdates      #run Final Updates
CleanUp           #remove install dir

echo "Advanced Flight Systems Upgrade Complete" >> $LOG_FILE

echo "Sending Restarting command to NXP" >> $LOG_FILE
echo "X" >> $NXP_PORT
echo "X" >> $NXP_PORT
echo "X" >> $NXP_PORT
sync
sleep 1

echo "Sending Reboot Command to OS" >> $LOG_FILE
reboot
: exit 0;
